/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.domain;

import com.portlandwebworks.commons.dao.DefaultOrderBy;

import javax.persistence.*;
import java.util.Date;

/**
 * This software is the property of Portland Webworks.
 *
 * The default ordering behavior of a user query is to order by lastName, firstName ascending.  You can apply your own
 * defaults by adding @DefaultOrderBy annotations to your subclass fields with priority values less than 100.
 *
 * @Author rnorthup
 */
@MappedSuperclass
public class UserEntityBase extends EntityBase
{
	@Column(length = 30, nullable = false, unique = true)
	private String login;

	@Column(name = "first_name", length = 30, nullable = false)
	@DefaultOrderBy(priority = 110)
	private String firstName;

	@Column(name = "last_name", length = 30, nullable = false)
	@DefaultOrderBy(priority = 100)
	private String lastName;

	@Column(name = "middle_initial")
	private Character middleInitial;

	@Column(name = "suffix", length = 10)
	private String suffix;

	@Column(name = "is_enabled", nullable = false)
	private boolean enabled;

	@Column(name = "last_login_date")
	private Date lastLoginDate;

	@Column(name = "email", length = 120)
	private String email;

	@Column(name = "creating_user_id")
	private Long creatingUserId;

	@Column(name = "created_date")
	private Date createdDate;

	@Column(name = "last_modifying_user_id")
	private Long lastModifyingUserId;

	@Column(name = "last_modified_date")
	private Date lastModifiedDate;

	
	public String getLogin()
	{
		return login;
	}

	public void setLogin(String login)
	{
		this.login = login;
	}

	public String getFirstName()
	{
		return firstName;
	}

	public void setFirstName(String firstName)
	{
		this.firstName = firstName;
	}

	public String getFirstAndLastName()
	{
		return getFirstName() + " " + getLastName();
	}

	public String getLastAndFirstName()
	{
		return getLastName() + ", " + getFirstName();
	}

	public String getLastName()
	{
		return lastName;
	}

	public void setLastName(String lastName)
	{
		this.lastName = lastName;
	}

	public Character getMiddleInitial()
	{
		return middleInitial;
	}

	public void setMiddleInitial(Character middleInitial)
	{
		this.middleInitial = middleInitial;
	}

	public String getSuffix()
	{
		return suffix;
	}

	public void setSuffix(String suffix)
	{
		this.suffix = suffix;
	}

	public boolean isEnabled()
	{
		return enabled;
	}

	public void setEnabled(boolean enabled)
	{
		this.enabled = enabled;
	}

	public Date getLastLoginDate()
	{
		return lastLoginDate;
	}

	public void setLastLoginDate(Date lastLoginDate)
	{
		this.lastLoginDate = lastLoginDate;
	}

	public String getEmail()
	{
		return email;
	}

	public void setEmail(String email)
	{
		this.email = email;
	}

	public Long getCreatingUserId()
	{
		return creatingUserId;
	}

	public void setCreatingUserId(Long creatingUserId)
	{
		this.creatingUserId = creatingUserId;
	}

	public Date getCreatedDate()
	{
		return createdDate;
	}

	public void setCreatedDate(Date createdDate)
	{
		this.createdDate = createdDate;
	}

	public Long getLastModifyingUserId()
	{
		return lastModifyingUserId;
	}

	public void setLastModifyingUserId(Long lastModifyingUserId)
	{
		this.lastModifyingUserId = lastModifyingUserId;
	}

	public Date getLastModifiedDate()
	{
		return lastModifiedDate;
	}

	public void setLastModifiedDate(Date lastModifiedDate)
	{
		this.lastModifiedDate = lastModifiedDate;
	}
}
