/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.reporting;

import com.portlandwebworks.commons.dao.Operator;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class ReportTotal
{
	private String displayName;

	/**
	 * The field name or path that was used as a restrictive criteria for totaling records, if any, beyond what was
	 * specified in the report criteria.
	 *
	 */
	private String drillDownField;

	/**
	 * The query operator that was used as a restrictive criteria
	 */
	private Operator drillDownOperator;

	/**
	 * The field value that was used as a restrictive criteria for totaling records, if any.
	 */
	private Object drillDownValue;

	private Long total;

	public ReportTotal()
	{
	}

	public ReportTotal(String displayName, Long total)
	{
		this.displayName = displayName;
		this.total = total;
	}

	public ReportTotal(String displayName, String drillDownField, Object drillDownValue, Long total)
	{
		this.displayName = displayName;
		this.drillDownField = drillDownField;
		this.drillDownValue = drillDownValue;
		this.total = total;
	}

	public ReportTotal(String displayName, String drillDownField, Operator drillDownOperator, Object drillDownValue, Long total)
	{
		this.displayName = displayName;
		this.drillDownField = drillDownField;
		this.drillDownOperator = drillDownOperator;
		this.drillDownValue = drillDownValue;
		this.total = total;
	}

	public String getDisplayName()
	{
		return displayName;
	}

	public void setDisplayName(String displayName)
	{
		this.displayName = displayName;
	}

	public String getDrillDownField()
	{
		return drillDownField;
	}

	public void setDrillDownField(String drillDownField)
	{
		this.drillDownField = drillDownField;
	}

	public Operator getDrillDownOperator()
	{
		return drillDownOperator;
	}

	public void setDrillDownOperator(Operator drillDownOperator)
	{
		this.drillDownOperator = drillDownOperator;
	}

	public Object getDrillDownValue()
	{
		return drillDownValue;
	}

	public void setDrillDownValue(Object drillDownValue)
	{
		this.drillDownValue = drillDownValue;
	}

	public Long getTotal()
	{
		return total;
	}

	public void setTotal(Long total)
	{
		this.total = total;
	}
}
