/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.test.dbunit;

import org.apache.log4j.Logger;
import org.dbunit.DatabaseUnitException;
import org.dbunit.database.IDatabaseConnection;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.xml.XmlDataSet;
import org.dbunit.operation.DatabaseOperation;
import org.springframework.test.context.TestContext;
import org.springframework.test.context.TestExecutionListener;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class DbUnitTestExecutionListener implements TestExecutionListener
{
	private static Logger logger = Logger.getLogger(DbUnitTestExecutionListener.class);

	private IDatabaseConnectionProvider dbConnProvider;


	public void beforeTestClass(TestContext testContext) throws Exception
	{
		DataSet dataSetAnnot = testContext.getTestClass().getAnnotation(DataSet.class);
		if (dataSetAnnot != null) {

			String filePath = dataSetAnnot.value();
			String operation = dataSetAnnot.operation();

			DbUnitUtils.doDatabaseOperation(
					testContext.getApplicationContext().getBean(IDatabaseConnectionProvider.class), filePath, operation);
		}
		else {
			DataSets dataSets = testContext.getTestClass().getAnnotation(DataSets.class);
			if (dataSets != null) {
				boolean first = true;
				for (DataSet dataSet : dataSets.value()) {
					String filePath = dataSet.value();
					String operation = dataSet.operation();

					if (! first) {
						// Default operation, when unspecified, is CLEAN_INSERT.  This default doesn't make sense when
						// datasets are applied in a series, so override the default here to be INSERT
						if (operation.equals("CLEAN_INSERT")) {
							operation = "INSERT";
						}
					}

					DbUnitUtils.doDatabaseOperation(
							testContext.getApplicationContext().getBean(IDatabaseConnectionProvider.class), filePath, operation);

					first = false;
				}
			}
		}
	}

	public void prepareTestInstance(TestContext testContext) throws Exception
	{
	}

	public void beforeTestMethod(TestContext testContext) throws Exception
	{
		DataSet dataSetAnnot = testContext.getTestMethod().getAnnotation(DataSet.class);
		if (dataSetAnnot != null) {

			String filePath = dataSetAnnot.value();
			String operation = dataSetAnnot.operation();

			DbUnitUtils.doDatabaseOperation(
					testContext.getApplicationContext().getBean(IDatabaseConnectionProvider.class), filePath, operation);
		}
		else {
			DataSets dataSets = testContext.getTestMethod().getAnnotation(DataSets.class);
			if (dataSets != null) {
				boolean first = true;
				for (DataSet dataSet : dataSets.value()) {
					String filePath = dataSet.value();
					String operation = dataSet.operation();

					if (! first) {
						// Default operation, when unspecified, is CLEAN_INSERT.  This default doesn't make sense when
						// datasets are applied in a series, so override the default here to be INSERT
						if (operation.equals("CLEAN_INSERT")) {
							operation = "INSERT";
						}
					}

					DbUnitUtils.doDatabaseOperation(
							testContext.getApplicationContext().getBean(IDatabaseConnectionProvider.class), filePath, operation);

					first = false;
				}
			}
		}
	}

	public void afterTestMethod(TestContext testContext) throws Exception
	{
	}

	public void afterTestClass(TestContext testContext) throws Exception
	{
	}
}
