package com.portlandwebworks.commons.validation;

import org.apache.commons.lang.StringUtils;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

/**
 * This software is the property of Portland Webworks.
 *
 * The Size validator built into hibernate validators does not ignore empty strings when validating string length.  This
 * one does.
 *
 * A JSR 303 validator will apply this validation to any field with the @SizeEmptyAllowed annotation assigned to it.
 *
 * @Author rnorthup
 */
public class ValidateSizeAllowEmpty implements ConstraintValidator<SizeEmptyAllowed, Object>
{
	int min;
	int max;

	public void initialize(SizeEmptyAllowed sizeEmptyAllowed)
	{
		this.min = sizeEmptyAllowed.min();
		this.max = sizeEmptyAllowed.max();
	}

	public boolean isValid(Object target, ConstraintValidatorContext context)
	{
		// Any empty value should be interpreted as passing validation.
		if (target == null) {
			return true;
		}

		// Special handling for strings--allow empty string
		if (target instanceof String) {
			if (StringUtils.isBlank((String)target)) {
				return true;
			}
			int strlen = ((String)target).length();
			return strlen >= min && strlen <= max;
		}

		return false;
	}
}
