/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.xstream;

import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import org.apache.commons.lang.time.DateFormatUtils;
import org.apache.commons.lang.time.DateUtils;

import java.text.MessageFormat;
import java.text.ParseException;
import java.util.Date;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class DateConverter implements Converter
{
	String[] formats = new String[] {
		"yyyy-MM-dd HH:mm:ss"
	};

	public void marshal(Object o, HierarchicalStreamWriter writer, MarshallingContext context)
	{
		Date date = (Date)o;
		writer.setValue(DateFormatUtils.format(date, formats[0]));
	}

	public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context)
	{
		try {
			return DateUtils.parseDate(reader.getValue(), formats);
		}
		catch (ParseException e) {
			throw new RuntimeException(MessageFormat.format("Unable to parse date {0} using pattern {1}",
					reader.getValue(), formats[0]));
		}
	}

	public boolean canConvert(Class clazz)
	{
		return clazz.equals(Date.class);
	}
}
